# Before `make install' is performed this script should be runnable with
# `make test'. After `make install' it should work as `perl test.pl'

###################################################################################################

# Change 1..1 below to 1..last_test_to_print .

use Test::More tests => 1;

use Shatterproof;

ok(1);
